@@ -1,10 +1,30 @@
+ /*
+ *  This file is part of the KDE Help Center
+ *
+ *  Copyright (C) 1999 Matthias Elter (me@kde.org)
+ *                2001 Stephan Kulow (coolo@kde.org)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 
 #ifndef KHC_MAINWINDOW_H
 #define KHC_MAINWINDOW_H
 
 #include <KXmlGuiWindow>
 
-#include <kparts/browserextension.h>
+#include <KParts/BrowserExtension>
 
 #include "glossary.h"
 
@@ -29,7 +49,7 @@ class MainWindow : public KXmlGuiWindow
 	Q_CLASSINFO("D-Bus Interface", "org.kde.khelpcenter.khelpcenter")
   public:
     MainWindow();
-    ~MainWindow();
+    ~MainWindow() override;
 
   public Q_SLOTS:
     Q_SCRIPTABLE void openUrl( const QString &url );
@@ -65,8 +85,8 @@ class MainWindow : public KXmlGuiWindow
                   const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
                   const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments() );
 
-    void saveProperties( KConfigGroup &config ) Q_DECL_OVERRIDE;
-    void readProperties( const KConfigGroup &config ) Q_DECL_OVERRIDE;
+    void saveProperties( KConfigGroup &config ) override;
+    void readProperties( const KConfigGroup &config ) override;
 
     void readConfig();
     void writeConfig();
